==> masonite-logging-0.0.1.tar.gz: masonite-logging-0.0.1/setup.py <==
from setuptools import setup

setup(
    name="masonite-logging",
    packages=[
        'masonite.logging',
        'masonite.logging.drivers',
        'masonite.logging.channels',
        'masonite.logging.managers',
        'masonite.logging.providers',
    ],
    package_dir={'': 'src'},
    include_package_data=True,
    version='0.0.1',
    install_requires=[],
    description="Validation Package",
    author="Joseph Mancuso",
    author_email='joe@masoniteproject.com',
    url='https://github.com/MasoniteFramework/masonite',
    keywords=['masonite', 'python web framework', 'python3'],
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        'Operating System :: OS Independent',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',

        'Topic :: Software Development :: Libraries',
        'Topic :: Utilities'
    ]
)

==> masonite-logging-1.0.0.tar.gz: masonite-logging-1.0.0/setup.py <==
from setuptools import setup

setup(
    name="masonite-logging",
    packages=[
        'masonite.logging',
        'masonite.logging.configs',
        'masonite.logging.drivers',
        'masonite.logging.channels',
        'masonite.logging.managers',
        'masonite.logging.providers',
    ],
    package_dir={'': 'src'},
    include_package_data=True,
    version='1.0.0',
    install_requires=[
        "masonite>=2.2.24"
    ],
    description="Validation Package",
    author="Joseph Mancuso",
    author_email='joe@masoniteproject.com',
    url='https://github.com/MasoniteFramework/masonite',
    keywords=['masonite', 'python web framework', 'python3'],
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        'Operating System :: OS Independent',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',

        'Topic :: Software Development :: Libraries',
        'Topic :: Utilities'
    ]
)
